#!/bin/bash

set -e
function cleanup()
{
	set +e
	[ -n "$tmp_file" ] && /bin/rm -f "$tmp_file"
	set -e
}

trap cleanup ERR

tmp_file=`tempfile`

cat > "$tmp_file" << EOF
###############################################################################
# DO NOT EDIT THIS FILE, IT IS GENERATED AUTOMATICALLY AND WILL BE OVERWRITTEN
# PLEASE USE /opt/k2/k2-xorg.conf-main AND /etc/evtouch/config INSTEAD
###############################################################################
EOF

# write hardware related sections to the temporary file
/bin/cat /opt/k2/k2-xorg.conf-main >> "$tmp_file"

# write k2-specific layouts to the temporary file
/bin/cat >> "$tmp_file" << EOF
############ SERVER FLAGS

Section "ServerFlags"
	Option         "BlankTime" "0"
	Option         "StandbyTime" "0"
	Option         "SuspendTime" "0"
	Option         "OffTime" "0"
	Option         "NoPM" "On"
	Option         "DPMS" "Off"
	Option         "AllowEmptyInput" "On"
	
EOF

if [[ -e "/etc/k2-auto-add-devices" ]]; then
	/bin/cat >> "$tmp_file" << EOF
	Option         "AutoAddDevices" "On"

EOF
else
	/bin/cat >> "$tmp_file" << EOF
	Option         "AutoAddDevices" "Off"

EOF
fi

/bin/cat >> "$tmp_file" << EOF
	Option         "DontVTSwitch" "On"
	Option         "DontZap" "On"
	Option         "DontZoom" "On"
	Option         "DisableVidModeExtension" "On"
	Option         "XkbDisable" "On"
EndSection

############ CALIBRATE LAYOUT SECTIONS

Section "ServerLayout"
	Identifier     "calibrate_layout"
#	Screen      0  "Screen0" 0 0
	Screen      0  "calibrate_screen" 0 0
	InputDevice    "Keyboard0" "CoreKeyboard"
	InputDevice    "Mouse0" "CorePointer"

	Option         "AutoAddDevices" "On"
	Option         "DontVTSwitch" "Off"
	Option         "DontZap" "Off"
EndSection

Section "Monitor"
	Identifier   "calibrate_monitor"
	VendorName   "Monitor Vendor"
	ModelName    "Monitor Model"
	Option       "DPMS" "Off"
EndSection

Section "Screen"
	Identifier "calibrate_screen"
	Device     "Card0"
	Monitor    "calibrate_monitor"
	SubSection "Display"
		Viewport   0 0
		Depth     24
	EndSubSection
EndSection

############ K2GUI LAYOUT SECTIONS

Section "ServerLayout"
	Identifier     "k2gui_layout"
	Screen      0  "k2gui_screen" 0 0
	InputDevice    "k2gui_touchscreen" "CorePointer"
EndSection

Section "Monitor"
	Identifier   "k2gui_monitor"
	VendorName   "Monitor Vendor"
	ModelName    "Monitor Model"
	Option       "Rotate" "right"
	Option       "DPMS" "Off"
EndSection

Section "Screen"
	Identifier "k2gui_screen"
	Device     "Card0"
	Monitor    "k2gui_monitor"
	SubSection "Display"
		Viewport   0 0
		Depth     24
	EndSubSection
EndSection

EOF

# write touchscreen input device section
if [ -f /etc/evtouch/config ]; then
	source /etc/evtouch/config
	/bin/cat >> "$tmp_file" << EOF
Section "InputDevice"
	Identifier  "k2gui_touchscreen"
	Driver      "evtouch"
	Option      "Device" "/dev/k2gui-touchscreen-event"
	Option      "ReportingMode" "Raw"
	Option      "SendCoreEvents" "On"

	Option      "maxx" "$MAXX"
	Option      "maxy" "$MAXY"
	Option      "minx" "$MINX"
	Option      "miny" "$MINY"
#	Option      "x0" "$X0"
#	Option      "y0" "$Y0"
#	Option      "x1" "$X1"
#	Option      "y1" "$Y1"
#	Option      "x2" "$X2"
#	Option      "y2" "$Y2"
#	Option      "x3" "$X3"
#	Option      "y3" "$Y3"
#	Option      "x4" "$X4"
#	Option      "y4" "$Y4"
#	Option      "x5" "$X5"
#	Option      "y5" "$Y5"
#	Option      "x6" "$X6"
#	Option      "y6" "$Y6"
#	Option      "x7" "$X7"
#	Option      "y7" "$Y7"
#	Option      "x8" "$X8"
#	Option      "y8" "$Y8"
	Option      "swapx" "1"
	Option      "movelimit" "30"
EndSection
EOF
else
	/bin/cat >> "$tmp_file" << EOF
Section "InputDevice"
	Identifier  "k2gui_touchscreen"
	Driver      "evtouch"
	Option      "Device" "/dev/k2gui-touchscreen-event"
	Option      "ReportingMode" "Raw"
	Option      "SendCoreEvents" "On"
EndSection
EOF

fi

/bin/mv -f "$tmp_file" /etc/X11/k2-xorg.conf

cleanup


