#!/bin/bash
#
# Выполняет обновление ПО графического интерфейса
#
# Специальные коды возврата:
#	64 - Не найден ни один пакет обновления (по имени файла); 
#	65 - Уже установлена более новая версия (по имени файла);
#	66 - Эта версия уже установлена (по имени файла);
#	67 - Файл поврежден (ошибка при разархивировании);


set -e

function cleanup()
{
	set +e
	/usr/bin/find /k2rep -maxdepth 1 -exec /bin/umount -l {} \; || true
	/bin/rm -Rf /k2rep_unpack /k2rep
	[ -n "$sources_list" ] && rm -f "$sources_list"
	set -e
}

function exit_error()
{
	cleanup
	exit $1
}

trap cleanup ERR

cd /

echo "Removing bad fonts..."
/usr/bin/apt-get -q -y purge ttf-kochi-mincho || echo "warning: ttf-kochi-mincho not purged"

echo "upgrade.sh: 'dpkg --status k2' output before upgrade:"
echo "`/usr/bin/dpkg --status k2`"

old_version=`/usr/bin/dpkg-query --showformat '${Version}' --show k2`

echo "upgrade.sh: will upgrade from version $old_version"

/usr/bin/find /k2rep -maxdepth 1 -exec /bin/umount -l {} \; || true
/bin/rm -Rf /k2rep
/bin/mkdir -p /k2rep

for dev in `/bin/ls -1 /dev/sd* | /bin/sed "s/\/dev\///g"`; do
	echo "upgrade.sh: testing $dev"
	is_supported=$(
		udev_env=`/usr/bin/udevinfo \
			--query=env \
			--name=/dev/$dev`
		eval "$udev_env"
		if [ "$ID_BUS" == "usb" -a "$ID_FS_TYPE" == "vfat" ];
		then
			echo "1"
		fi
	) || true
# mount all suitable devices
	if [ -n "$is_supported" ]; then
		echo "upgrade.sh: try to mount device $dev"
		mkdir "/k2rep/$dev"
		/bin/mount \
			-t vfat \
			-o ro,utf8,nodev,noexec,nosuid \
			"/dev/$dev" "/k2rep/$dev" || true
	fi
done

list=`find \
	/k2rep \
	-regextype grep \
	-regex "/k2rep/sd../k2rep-[0-9]\{8\}-[0-9]\{6\}\.tgz$"`
file_to_use=""
max=""
for f in $list; do
	echo "upgrade.sh: $f"
	n=`/usr/bin/basename "$f"`
	if [ "$n" \> "$max" ]; then
		max=$n
		file_to_use=$f
	fi
done

if [[ $file_to_use = "" ]]; then exit_error 64; fi

new_version=`echo $file_to_use | tail -c20`
if [[ $new_version < $old_version".tgz" ]]; then exit_error 65; fi
if [[ $new_version = $old_version".tgz" ]]; then exit_error 66; fi

echo "upgrade.sh: using file $file_to_use"

/bin/rm -Rf /k2rep_unpack
/bin/mkdir -p /k2rep_unpack
cd /k2rep_unpack
/bin/tar xzf "$file_to_use" || exit_error 67

sources_list=`tempfile`
echo "deb file:///k2rep_unpack/k2rep k2 main" > "$sources_list"
# --yes --force-yes --allow-unauthenticated
APT_FLAGS="-o Dir::Etc::SourceList=$sources_list \
	--yes -qq"

/usr/bin/dpkg --configure -a || true
/usr/bin/apt-get $APT_FLAGS update
/usr/bin/apt-get $APT_FLAGS dist-upgrade

echo "upgrade.sh: 'dpkg --status k2' output after upgrade:"
echo "`/usr/bin/dpkg --status k2`"

new_version=`/usr/bin/dpkg-query --showformat '${Version}' --show k2`


cleanup

if [ "$new_version" == "$old_version" ]; then
	echo "upgrade.sh: k2 version is not changed"
	exit 100
else
	echo "upgrade.sh: success"
	exit 0
fi


